Index: src/global-handles.h |
diff --git a/src/global-handles.h b/src/global-handles.h |
index 866317ee139977a199c89ccb07d6be478bed073a..482baef3fa4b62a0c05be194a94163967a4e18cb 100644 |
--- a/src/global-handles.h |
+++ b/src/global-handles.h |
@@ -155,6 +155,9 @@ class GlobalHandles { |
// Clear the weakness of a global handle. |
void MarkIndependent(Object** location); |
+ // Mark the reference to this object externaly unreachable. |
+ void MarkPartiallyDependent(Object** location); |
+ |
static bool IsIndependent(Object** location); |
// Tells whether global handle is near death. |
@@ -195,16 +198,17 @@ class GlobalHandles { |
// Iterates over strong and dependent handles. See the node above. |
void IterateNewSpaceStrongAndDependentRoots(ObjectVisitor* v); |
// Finds weak independent handles satisfying the callback predicate |
// and marks them as pending. See the note above. |
void IdentifyNewSpaceWeakIndependentHandles(WeakSlotCallbackWithHeap f); |
// Iterates over weak independent handles. See the note above. |
void IterateNewSpaceWeakIndependentRoots(ObjectVisitor* v); |
// Add an object group. |
// Should be only used in GC callback function before a collection. |
- // All groups are destroyed after a mark-compact collection. |
+ // All groups are destroyed after a garbage collection. |
void AddObjectGroup(Object*** handles, |
size_t length, |
v8::RetainedObjectInfo* info); |
@@ -195,16 +198,17 @@ class GlobalHandles { |
// Iterates over strong and dependent handles. See the node above. |
void IterateNewSpaceStrongAndDependentRoots(ObjectVisitor* v); |
- // Finds weak independent handles satisfying the callback predicate |
- // and marks them as pending. See the note above. |
+ // Finds weak independent or partially independent handles satisfying |
+ // the callback predicate and marks them as pending. See the note above. |
void IdentifyNewSpaceWeakIndependentHandles(WeakSlotCallbackWithHeap f); |
@@ -195,16 +198,17 @@ class GlobalHandles { |
void IdentifyNewSpaceWeakIndependentHandles(WeakSlotCallbackWithHeap f); |
- // Iterates over weak independent handles. See the note above. |
+ // Iterates over weak independent or partially independent handles. |
+ // See the note above. |
void IterateNewSpaceWeakIndependentRoots(ObjectVisitor* v); |
// Add an object group. |